% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.



% Isocitrate Dehydrogenase (EC 1.1.1.41) reaction.


% Note: pH (H+) gives some negative values...
% Warning: Imaginary parts of complex X and/or Y arguments ignored 
% In IDH_Script (line 49) 

clear all;

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.1;     % Vmf_IDH
T = 25;           % Temperature

% (2.) Setting initial values
xo(1) = 3e-3;       % Isocitrate (M)
xo(2) = 5e-4;       % NAD (M)
xo(3) = 1e-3;       % Ketogluterate (M)
xo(4) = 5e-4;       % NADH (M)
xo(5) = 1e-3;       % CO2 (M)
xo(6) = 1e-3;       % ATP (M)
xo(7) = 1e-4;       % ADP (M)
xo(8) = 1e-7;       % [H] (M)
xo(9) = 1e-3;       % [Mg] (M)
xo(10) = 150e-3;    % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode45(@IDH,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,3)*1e3,'k:');
set(p,'linewidth',1.5);
text(1,2.75,'Isocitrate','Fontsize',14);
text(1,1.25,'Ketogluterate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,7)*1e3,'k-',t,x(:,6)*1e3,'k:',t,x(:,5)*1e3,'ko');
set(p,'linewidth',1.5);
text(5,.9,'ATP','Fontsize',14);
text(5,.2,'ADP','Fontsize',14);
text(5,1.4,'CO2','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,8)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(4); p = plot(t,x(:,2)*1e3,'k-',t,x(:,4)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,1.25,'NADH','Fontsize',14);
text(5,.25,'NAD','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_IsoCit','BISEN_NAD','BISEN_Keto','NADH', 'CO2', 'ATP','ADP','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'IDHBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'IDHBisenOutput.csv';
writetable(Table,filename);
%%
